Package: Greg
Version: 2.0.3
Title: Regression Helper Functions
Maintainer: Max Gordon <max@gforge.se>
Authors@R: c(person("Max", "Gordon", email = "max@gforge.se", role = c("aut", "cre")),
             person("Reinhard", "Seifert", role = "aut", comment = "Author of original plotHR"))
Description: Methods for manipulating regression models and for describing these in a style adapted for medical journals.
  Contains functions for generating an HTML table with crude and adjusted estimates, plotting hazard ratio, plotting model
  estimates and confidence intervals using forest plots, extending this to comparing multiple models in a single forest plots.
  In addition to the descriptive methods, there are functions for the robust covariance matrix provided by the 'sandwich'
  package, a function for adding non-linearities to a model, and a wrapper around the 'Epi' package's Lexis() functions for
  time-splitting a dataset when modeling non-proportional hazards in Cox regressions.
License: GPL (>= 3)
URL: http://gforge.se
BugReports: https://github.com/gforge/Greg/issues
Biarch: yes
Encoding: UTF-8
Imports: broom, Epi, dplyr, glue, graphics, grDevices, htmlTable (>=
        2.0.0), Hmisc, knitr, methods, nlme, purrr, rlang, rms,
        sandwich, stats, stringr, tibble, tidyr, tidyselect, utils
Depends: Gmisc (>= 1.0.3), forestplot, R (>= 4.1.0)
Suggests: boot, testthat, cmprsk, survival, ggplot2, parallel,
        rmarkdown, rmeta, tidyverse
VignetteBuilder: knitr
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-19 06:31:38 UTC; max
Author: Max Gordon [aut, cre],
  Reinhard Seifert [aut] (Author of original plotHR)
Repository: CRAN
Date/Publication: 2025-08-19 07:40:02 UTC
Built: R 4.6.0; ; 2026-04-30 12:10:19 UTC; unix
