# Generated by roxygen2: do not edit by hand

S3method("[",getCrudeAndAdjustedModelData)
S3method("[",printCrudeAndAdjusted)
S3method(addNonlinearity,coxph)
S3method(addNonlinearity,default)
S3method(addNonlinearity,glm)
S3method(addNonlinearity,lm)
S3method(addNonlinearity,negbin)
S3method(addNonlinearity,rms)
S3method(bread,ols)
S3method(cbind,printCrudeAndAdjusted)
S3method(confint,ols)
S3method(estfun,ols)
S3method(forestplot,forestplotRegrObj.grouped)
S3method(forestplot,forestplotRegrObj.single)
S3method(forestplotRegrObj,coxph)
S3method(forestplotRegrObj,default)
S3method(forestplotRegrObj,glm)
S3method(forestplotRegrObj,list)
S3method(forestplotRegrObj,lm)
S3method(forestplotRegrObj,lrm)
S3method(getCrudeAndAdjustedModelData,default)
S3method(getCrudeAndAdjustedModelData,rms)
S3method(hatvalues,ols)
S3method(htmlTable,printCrudeAndAdjusted)
S3method(knit_print,printCrudeAndAdjusted)
S3method(latex,printCrudeAndAdjusted)
S3method(model.matrix,ols)
S3method(plot,plotHR)
S3method(print,forestplotRegrObj.grouped)
S3method(print,forestplotRegrObj.single)
S3method(print,plotHR)
S3method(print,printCrudeAndAdjusted)
S3method(print,simpleRmsAnova)
S3method(rbind,printCrudeAndAdjusted)
S3method(tidy,rms)
export(addNonlinearity)
export(caDescribeOpts)
export(confint_robust)
export(forestplotCombineRegrObj)
export(forestplotRegrObj)
export(fpBoxSize)
export(getCrudeAndAdjustedModelData)
export(isFitCoxPH)
export(isFitLogit)
export(plotHR)
export(printCrudeAndAdjustedModel)
export(robcov_alt)
export(simpleRmsAnova)
export(timeSplitter)
import(forestplot)
import(htmlTable)
import(parallel)
import(utils)
importFrom(Epi,Lexis)
importFrom(Epi,cal.yr)
importFrom(Epi,splitLexis)
importFrom(Gmisc,copyAllNewAttributes)
importFrom(Gmisc,describeFactors)
importFrom(Gmisc,describeMean)
importFrom(Gmisc,fastDoCall)
importFrom(Gmisc,getDescriptionStatsBy)
importFrom(Gmisc,insertRowAndKeepAttr)
importFrom(Hmisc,label)
importFrom(Hmisc,latex)
importFrom(Hmisc,latexTranslate)
importFrom(broom,tidy)
importFrom(dplyr,across)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(dplyr,one_of)
importFrom(dplyr,row_number)
importFrom(glue,glue)
importFrom(grDevices,grey)
importFrom(graphics,axTicks)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(htmlTable,txtRound)
importFrom(knitr,asis_output)
importFrom(knitr,knit_print)
importFrom(methods,setClass)
importFrom(nlme,intervals)
importFrom(purrr,pluck)
importFrom(rlang,as_name)
importFrom(rms,bootcov)
importFrom(rms,contrast)
importFrom(rms,ols)
importFrom(rms,ols.influence)
importFrom(rms,robcov)
importFrom(sandwich,bread)
importFrom(sandwich,estfun)
importFrom(sandwich,vcovHC)
importFrom(sandwich,vcovHC.default)
importFrom(stats,AIC)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,family)
importFrom(stats,fivenum)
importFrom(stats,formula)
importFrom(stats,frequency)
importFrom(stats,get_all_vars)
importFrom(stats,hatvalues)
importFrom(stats,is.ts)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,naresid)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,start)
importFrom(stats,terms)
importFrom(stats,ts)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(stats,weights)
importFrom(stringr,str_detect)
importFrom(stringr,str_replace)
importFrom(stringr,str_split)
importFrom(stringr,str_trim)
importFrom(tibble,tibble)
importFrom(tidyr,separate)
importFrom(tidyselect,starts_with)
